@@ -31,17 +31,20 @@
 enum {
 	ACT_NULL,
 	ACT_COMPILE,
-	ACT_SAVE,
 	ACT_UPDATE,
+	ACT_ADD_BOOKMARK,
+	ACT_SAVE,
 	ACT_AUTOTRANSLATE,
 	ACT_REMOVE_ALL_TRANSLATIONS,
 	ACT_SAVE_AS,
 	ACT_REVERT,
 	ACT_CLOSE,
 	/***********************/
+#ifdef UTF8_CODE
 	ACT_IMPORT_UTF8,
 	ACT_EXPORT_UTF8,
 	/***********************/
+#endif
 	ACT_UNDO,
 	ACT_CUT,
 	ACT_COPY,
