@@ -20,10 +20,10 @@
 #ifndef GTR_DEFINES
 #define GTR_DEFINES 1
 
-#define BUILD_STRING	"1.0.2 -- 2004-04-08 17:58:38"
-#define BUILD_VERSIONS	"2.4.0 / 2.4.0 / 2.5.90.1 / 2.6.7"
-#define SCHEMESDIR	"/usr/local/share/gtranslator/colorschemes"
-#define SCRIPTSDIR	"/usr/local/share/gtranslator/scripts"
-#define WINDOW_ICON	"/usr/local/share/pixmaps/gtranslator.png"
+#define BUILD_STRING	"1.1.5 -- 2004-05-28 21:37:53"
+#define BUILD_VERSIONS	"2.5.0 / 2.5.0 / 2.6.1.1 / 2.6.10"
+#define SCHEMESDIR	"/usr/share/gtranslator/colorschemes"
+#define SCRIPTSDIR	"/usr/share/gtranslator/scripts"
+#define WINDOW_ICON	"/usr/share/pixmaps/gtranslator.png"
 
 #endif
