@@ -2,6 +2,7 @@
  * (C) 2000-2003 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
  *			Peeter Vois <peeter@gtranslator.org>
+ *			Ross Golder <ross@gtranslator.org>
  * 
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,11 +26,11 @@
 #include <gnome.h>
 
 #include "actions.h"
+#include "bookmark.h"
 #include "color-schemes.h"
-#include "defines.include"
+#include "defines.h"
 #include "dialogs.h"
 #include "gui.h"
-#include "htmlizer.h"
 #include "learn.h"
 #include "open.h"
 #include "parse.h"
@@ -42,6 +43,9 @@
 #include "utils.h"
 #include "utils_gui.h"
 
+#include <locale.h>
+#include <libintl.h>
+
 #include <signal.h>
 
 #include <gmodule.h>
@@ -61,14 +65,12 @@
  * The static variables used in the poptTable.
  */
 static gchar 	*gtranslator_geometry=NULL;
-static gchar 	*save_html_output_file=NULL;
 static gchar	*learn_file=NULL;
 static gchar	*auto_translate_file=NULL;
 static gchar	*exporting_po_file=NULL;
+
 static gboolean	build_information=FALSE;
-static gboolean	no_modules=FALSE;
-gboolean 	nosyntax=FALSE;
-gboolean	open_anyway=FALSE;
+static gboolean learn_statistics=FALSE;
 
 /*
  * gtranslator's option table.
@@ -80,11 +82,11 @@ static struct poptOption gtranslator_options[] = {
 	},
 	{
 		"auto-translate", 'a', POPT_ARG_STRING, &auto_translate_file,
-		0, N_("Auto translate the po file & exit"), N_("FILENAME")
+		0, N_("Auto translate the po file"), N_("FILENAME")
 	},
 	{
 		"build-information", 'b', POPT_ARG_NONE, &build_information,
-		0, N_("Show build information/specifications"), NULL
+		0, N_("Show build specifications"), NULL
 	},
 	{
 		"export-learn-buffer", 'e', POPT_ARG_STRING, &exporting_po_file,
@@ -96,35 +98,32 @@ static struct poptOption gtranslator_options[] = {
 	},
 	{
 		"learn", 'l', POPT_ARG_STRING, &learn_file,
-		0, N_("Learn the file completely & exit"), N_("FILENAME")
+		0, N_("Learn the file completely"), N_("FILENAME")
 	},
 	{
-		"webalize", 'w', POPT_ARG_STRING, &save_html_output_file,
-		0, N_("HTML file to write to"), N_("HTMLFILE")
-	},
-	{
-		"nosyntax", 'y', POPT_ARG_NONE, &nosyntax,
-		0, N_("Don't highlight syntax - FIXME: We're always non-syntaxed currently! Sorry..."), NULL 
+		"learn-statistics", 's', POPT_ARG_NONE, &learn_statistics,
+		0, N_("Show learn buffer statistics"), NULL
 	},
 	POPT_AUTOHELP {NULL}
 };
 
 int main(int argc, char *argv[])
 {
+	GnomeProgram    *program=NULL;
 	GnomeClient 	*client=NULL;
 	GnomeClientFlags flags;
 	
 	poptContext 	context;
 	
 	const char 	**args=NULL;
-	
+	GValue value = { 0, };
+
 	GError		*error=NULL;
 
 	/*
 	 * Initialize gettext.
 	 */ 
-	bindtextdomain(PACKAGE, GNOMELOCALEDIR);
-	bind_textdomain_codeset(PACKAGE, "UTF-8");
+	bindtextdomain(PACKAGE, DATADIR "/locale");
 	textdomain(PACKAGE);
 
 	/*
@@ -152,17 +151,22 @@ int main(int argc, char *argv[])
 
 		g_clear_error(&error);
 	}
-	
+
+	/*
+	 * Grab popt context
+	 */
+
 	/*
 	 * Initialize gtranslator within libgnomeui.
 	 */
-	gnome_program_init("gtranslator", VERSION, LIBGNOMEUI_MODULE, 
+	setlocale(LC_ALL, "");
+	program = gnome_program_init(PACKAGE, VERSION, LIBGNOMEUI_MODULE, 
 			   argc, argv,
 			   GNOME_PARAM_POPT_TABLE, gtranslator_options, 
 			   GNOME_PROGRAM_STANDARD_PROPERTIES,
 			   NULL);
-	/* XXX fix it! */
-	// 0, &context);
+	context = gnome_program_preinit(program, PACKAGE, VERSION, argc, argv);
+	bind_textdomain_codeset(PACKAGE, "UTF-8");
 
 	/*
 	 * Show up build information if desired.
@@ -186,7 +190,7 @@ int main(int argc, char *argv[])
 		g_print(_("Window icon:"));
 		NICE_PRINT(WINDOW_ICON);
 		g_print(_("Own locale directory:"));
-		NICE_PRINT(GNOMELOCALEDIR);
+		NICE_PRINT(DATADIR "/locale");
 		g_print(_("Default learn buffer file location:"));
 		NICE_PRINT("~/.gtranslator/umtf/personal-learn-buffer.xml");
 		g_print("\n");
@@ -252,7 +256,7 @@ int main(int argc, char *argv[])
 	/* 
 	 * Create the main app-window. 
 	 */
-	if(!auto_translate_file || !learn_file)
+	if(!auto_translate_file || !learn_file || !learn_statistics)
 	{
 		gtranslator_create_main_window();
 		gtranslator_utils_restore_geometry(gtranslator_geometry);
@@ -280,7 +284,7 @@ int main(int argc, char *argv[])
 		gtranslator_rescue_file_dialog();
 	}
 
-	if(!auto_translate_file || !learn_file)
+	if(!auto_translate_file || !learn_file || !learn_statistics)
 	{
 		/*
 		 * Load the applied color scheme from the prefs and check it; if it
@@ -295,11 +299,7 @@ int main(int argc, char *argv[])
 		}
 	}
 	
-	/*
-	 * If there are any files given on command line, open them
-	 */
 	file_opened = FALSE;
-	//	args = poptGetArgs(context);
 
 	/*
 	 * Auto translate the given file argument and exit without starting the
@@ -354,21 +354,18 @@ int main(int argc, char *argv[])
 	 * Open up the arguments as files (for now, only the first file is
 	 *  opened).
 	 */
+	g_value_init (&value, G_TYPE_POINTER);
+	g_object_get_property (G_OBJECT (program), GNOME_PARAM_POPT_CONTEXT, &value);
+	context = g_value_get_pointer (&value);
+	g_value_unset (&value);
+
+	args = poptGetArgs(context);
 	if (args)
 	{
 		/*
 		 * Try to open up the supported "special" gettext file types.
 		 */ 
 		gtranslator_open_file((gchar *)args[0]);
-
-		/*
-		 * Also write the HTML output of the given file if
-		 *  desired.
-		 */  
-		if(save_html_output_file)
-		{
-			gtranslator_htmlizer(save_html_output_file);
-		}
 	}
 	
 	//	poptFreeContext(context);
@@ -381,7 +378,7 @@ int main(int argc, char *argv[])
 		gtranslator_actions_set_up_state_no_file();
 	}
 	
-	if(!auto_translate_file || !learn_file)
+	if(!auto_translate_file || !learn_file || !learn_statistics)
 	{
 		/*
 		 * Check the session client flags, and restore state if needed 
@@ -399,6 +396,25 @@ int main(int argc, char *argv[])
 	 */
 	gtranslator_learn_init();
 
+	/*
+	 * If desired, just show a small information tidbit of the learn buffer cakes.
+	 */
+	if(learn_statistics)
+	{
+		gtranslator_learn_statistics();
+		gtranslator_learn_shutdown();
+
+		gtranslator_translator_free(gtranslator_translator);
+		gtranslator_preferences_free();
+
+		if(gnome_vfs_initialized())
+		{
+			gnome_vfs_shutdown();
+		}
+
+		return 0;
+	}
+
 	/*
 	 * Check if any filename for learning was supplied and if yes, learn
 	 *  the file completely, shutdown the learn buffer & exit afterwards.
@@ -440,7 +456,7 @@ int main(int argc, char *argv[])
 		 * As everything seemed to went fine, print out a nice
 		 *  message informing the user about the success.
 		 */
-		g_print(_("Learned `%s' successfully.\n"), learn_file);
+		g_print(_("Learned file `%s' successfully for your learn buffer.\n"), learn_file);
 
 		return 0;
 	}
@@ -482,7 +498,7 @@ int main(int argc, char *argv[])
 		/*
 		 * Give us another small status feedback about the export.
 		 */
-		g_print(_("Exported learn buffer to `%s'.\n"), exporting_po_file);
+		g_print(_("Exported learn buffer to file `%s'.\n"), exporting_po_file);
 
 		return 0;
 	}
@@ -499,6 +515,14 @@ int main(int argc, char *argv[])
 	 *  main menu.
 	 */
 	gtranslator_color_scheme_show_list();
+
+	/*
+	 * Load our possibly existing bookmarks' list from our preferences
+	 *  settings - shall make easy access to problematic messages
+	 *   possible and make life faster and easier.
+	 */
+	gtranslator_bookmark_load_list();
+	gtranslator_bookmark_show_list();
 	
 	gtk_main();
 	return 0;
