@@ -134,8 +134,8 @@ gint gtranslator_utils_stringlist_strcasecmp(GList *list, const gchar *string);
 /*
  * Get the right localename/charset for the language.
  */
-gchar *gtranslator_utils_get_locale_name(void);
-gchar *gtranslator_utils_get_locale_charset(void);
+gchar *gtranslator_utils_get_locale_name(GtrPo *po);
+gchar *gtranslator_utils_get_locale_charset(GtrPo *po);
 
 /*
  * The lists for the language informations -- are all changed 
@@ -151,11 +151,6 @@ void gtranslator_utils_language_lists_create(void);
 gboolean gtranslator_utils_language_lists_free(GtkWidget *widget, 
 	gpointer useless);
 
-/*
- * Convert the fg/bg settings from < 2001-03-03 to the new places.
- */
-void gtranslator_utils_old_colors_to_new_location(void);
-
 /*
  * Setup the real language names ala "tr_TR" to get the localized values
  *  for the given "halfwise" language name.
@@ -167,7 +162,6 @@ gchar *gtranslator_utils_get_full_language_name(gchar *lang);
  */
 gchar *gtranslator_utils_getline (FILE* stream);
 
-
 /*
  * These functions are all taken from GAL and integrated simply to here.
  */
